@@ -3,8 +3,6 @@ package Catalyst::Plugin::ConfigLoader::JSON;
 use strict;
 use warnings;
 
-use File::Slurp;
-
 =head1 NAME
 
 Catalyst::Plugin::ConfigLoader::JSON - Load JSON config files
@@ -42,7 +40,9 @@ sub load {
     my $class = shift;
     my $file  = shift;
 
-    my $content = read_file( $file );
+    open( my $fh, $file ) or die $!;
+    my $content = do { local $/; <$fh> };
+    close $fh;
 
     eval { require JSON::Syck; };
     if( $@ ) {
