@@ -2,5 +2,6 @@
 	name               => 'TestApp',
 	Controller::Config => {
 		foo => 'foo'
-	}
+	},
+	cache              => '__HOME__/cache',
 }
